@@ -1379,11 +1379,11 @@ class TestLibTesseractPDF(BaseTest):
 
     def setUp(self):
         self.image = Image.new(mode="RGB", size=(1, 1))
-        self.handle = randint(0, 2**32-1)
+        self.handle = 1234567
 
     @patch("pyocr.libtesseract.tesseract_raw")
     def test_pdf(self, raw):
-        renderer = randint(0, 2**32-1)
+        renderer = 2345671
         raw.init.return_value = self.handle
         raw.init_pdf_renderer.return_value = renderer
         libtesseract.image_to_pdf(self.image, "output")
@@ -1393,7 +1393,6 @@ class TestLibTesseractPDF(BaseTest):
         raw.set_page_seg_mode.assert_called_once_with(
             self.handle, raw.PageSegMode.AUTO_OSD
         )
-        raw.set_input_name.assert_called_once_with(self.handle, "stdin")
         raw.recognize.assert_called_once_with(self.handle)
         raw.init_pdf_renderer.assert_called_once_with(
             self.handle, "output", False
@@ -1407,6 +1406,41 @@ class TestLibTesseractPDF(BaseTest):
             [call(self.handle), call(renderer)]
         )
 
+    @patch("pyocr.libtesseract.tesseract_raw")
+    def test_multipage_pdf(self, raw):
+        renderer = 2345671
+        raw.init.return_value = self.handle
+        raw.init_pdf_renderer.return_value = renderer
+        libtesseract.LibtesseractPdfBuilder() \
+            .set_output_file("output")\
+            .add_image(self.image)\
+            .add_image(self.image)\
+            .build()
+
+        raw.init.assert_called_once_with(lang=None)
+        raw.set_image.assert_called_with(self.handle, self.image)
+        raw.set_image.assert_called_with(self.handle, self.image)
+        raw.set_page_seg_mode.assert_called_once_with(
+            self.handle, raw.PageSegMode.AUTO_OSD
+        )
+        raw.recognize.assert_called_with(self.handle)
+        raw.recognize.assert_called_with(self.handle)
+        raw.init_pdf_renderer.assert_called_once_with(
+            self.handle, "output", False
+        )
+        raw.begin_document.assert_called_once_with(renderer, "")
+        raw.add_renderer_image.assert_called_with(
+            self.handle, renderer
+        )
+        raw.add_renderer_image.assert_called_with(
+            self.handle, renderer
+        )
+        raw.end_document.assert_called_once_with(renderer)
+        self.assertListEqual(
+            raw.cleanup.call_args_list,
+            [call(self.handle), call(renderer)]
+        )
+
     @patch("pyocr.libtesseract.tesseract_raw")
     def test_pdf_renderer_error(self, raw):
         renderer = None
@@ -1417,15 +1451,15 @@ class TestLibTesseractPDF(BaseTest):
             libtesseract.image_to_pdf(self.image, "output")
 
         raw.init.assert_called_once_with(lang=None)
-        raw.set_image.assert_called_once_with(self.handle, self.image)
         raw.set_page_seg_mode.assert_called_once_with(
             self.handle, raw.PageSegMode.AUTO_OSD
         )
-        raw.set_input_name.assert_called_once_with(self.handle, "stdin")
-        raw.recognize.assert_called_once_with(self.handle)
         raw.init_pdf_renderer.assert_called_once_with(
             self.handle, "output", False
         )
+        self.assertFalse(raw.set_image.called)
+        self.assertFalse(raw.set_input_name.called)
+        self.assertFalse(raw.recognize.called)
         self.assertFalse(raw.begin_document.called)
         self.assertFalse(raw.add_renderer_image.called)
         self.assertFalse(raw.end_document.called)
